Modified bgp file name according to naming convention.

Change-Id: I403139b53fbc1a2dba894dfd39720707a52ba7cd
diff --git a/bgp/bgpio/src/main/java/org/onosproject/bgpio/protocol/Writeable.java b/bgp/bgpio/src/main/java/org/onosproject/bgpio/protocol/Writeable.java
index 72df7f3..1c6f7fc 100755
--- a/bgp/bgpio/src/main/java/org/onosproject/bgpio/protocol/Writeable.java
+++ b/bgp/bgpio/src/main/java/org/onosproject/bgpio/protocol/Writeable.java
@@ -17,7 +17,7 @@
 package org.onosproject.bgpio.protocol;
 
 import org.jboss.netty.buffer.ChannelBuffer;
-import org.onosproject.bgpio.exceptions.BGPParseException;
+import org.onosproject.bgpio.exceptions.BgpParseException;
 
 /**
  * Abstraction of an entity providing functionality to write byte streams of
@@ -29,7 +29,7 @@
      * Writes byte streams of messages to channel buffer.
      *
      * @param cb channelBuffer
      * @throws BGPParseException when error occurs while writing BGP message to channel buffer
      */
-    void writeTo(ChannelBuffer cb) throws BGPParseException;
+    void writeTo(ChannelBuffer cb) throws BgpParseException;
 }
\ No newline at end of file
@@ -29,7 +29,7 @@
      *
      * @param cb channelBuffer
-     * @throws BGPParseException when error occurs while writing BGP message to channel buffer
+     * @throws BgpParseException when error occurs while writing BGP message to channel buffer
      */